# 'Above-the-line' deductions

Above-the-line deductions are deductions made from gross income to arrive at adjusted gross income. The Code refers to deductions by their section; below is an in-progress table of the sections and their deductions.

| Section | Deduction |
| --- | --- |
| [85](https://www.law.cornell.edu/uscode/text/26/85) | Unemployment compensation |
| [86](https://www.law.cornell.edu/uscode/text/26/86) | Social security |
| [135](https://www.law.cornell.edu/uscode/text/26/135) | Tuition fees |
| [137](https://www.law.cornell.edu/uscode/text/26/137) | Adoption expenses |
| [199](https://www.law.cornell.edu/uscode/text/26/199) | Domestic production activities (repealed) |
| [219](https://www.law.cornell.edu/uscode/text/26/219) | Retirement savings |
| [221](https://www.law.cornell.edu/uscode/text/26/221) | Education/student loan interest |
| [222](https://www.law.cornell.edu/uscode/text/26/222) | Qualified tuition expenses (repealed) |
| [223](https://www.law.cornell.edu/uscode/text/26/223) | Health savings accounts |
| [469](https://www.law.cornell.edu/uscode/text/26/469) | Passive activity |
| [911](https://www.law.cornell.edu/uscode/text/26/911) | Foreign earned income |
| [933](https://www.law.cornell.edu/uscode/text/26/933) | Income from Puerto Rico |